import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def add_scrollback(text, text_type) -> None: ...
def autocomplete(_context) -> None: ...
def banner(context) -> None: ...
def execute(context, _is_interactive) -> None: ...
def shell_run(text) -> None: ...
